plot_balance: Plot the balance

View source: R/plot_balance.R

plot_balanceR Documentation

Plot the balance

Description

Visualize balance of variables between treatment and control groups. Balance plot reflects balance in standardized units.

Usage

plot_balance(.data, treatment, confounders)

Arguments

.data

dataframe

treatment

the column denoted treatment. Must be binary.

confounders

character list of column names denoting the X columns of interest

Value

ggplot object

Author(s)

Joseph Marlo

Examples

data(lalonde)
plot_balance(lalonde, 'treat', c('re78', 'age', 'educ')) + labs(title = 'My new title')

plotBart documentation built on May 27, 2022, 9:12 a.m.