View source: R/plot_overlap_pScores.R
| plot_overlap_pScores | R Documentation |
Plot histograms showing the overlap between propensity scores by treatment status.
plot_overlap_pScores(
.data,
treatment,
response,
confounders,
plot_type = c("histogram", "density"),
pscores = NULL,
...
)
.data |
dataframe |
treatment |
character. Name of the treatment column within .data |
response |
character. Name of the response column within .data |
confounders |
character list of column names denoting confounders within .data |
plot_type |
the plot type, one of c('Histogram', 'Density') |
pscores |
propensity scores. If not provided, then propensity scores will be calculated using BART |
... |
additional arguments passed to 'bartCause::bartc' propensity score calculation |
ggplot object
George Perrett, Joseph Marlo
plot_overlap_vars
data(lalonde)
plot_overlap_pScores(
.data = lalonde,
treatment = 'treat',
response = 're78',
confounders = c('age', 'educ'),
plot_type = 'histogram',
pscores = NULL,
seed = 44
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.